#! /bin/sh
#
# A simple script to install the pre-compiled binaries. It takes one
# argument, the type of executable used by the machine.

if [ $# = 0 ]; then
	echo "usage: install.sh ELF|a.out"
	exit 1
fi

if [ $1 != ELF -a $1 != a.out ]; then
	echo "install.sh: invalid binary type $1"
	exit 1
fi

if [ $1 = ELF ]; then
	echo "Installing ELF binaries..."

	install -m 755 -s -o bin -g bin bin-ELF/call      /usr/local/bin
	install -m 4755 -s -o root -g bin bin-ELF/listen  /usr/local/bin
	install -m 755 -s -o bin -g bin bin-ELF/mheard    /usr/local/bin
	install -m 755 -s -o bin -g bin bin-ELF/pms       /usr/local/bin
	install -m 755 -s -o bin -g bin bin-ELF/axattach  /usr/local/sbin
	install -m 755 -s -o bin -g bin bin-ELF/ax25d     /usr/local/sbin
	install -m 755 -s -o bin -g bin bin-ELF/axl       /usr/local/sbin
	install -m 755 -s -o bin -g bin bin-ELF/axparms   /usr/local/sbin
	install -m 755 -s -o bin -g bin bin-ELF/beacon    /usr/local/sbin
	install -m 755 -s -o bin -g bin bin-ELF/kissparms /usr/local/sbin
	install -m 755 -s -o bin -g bin bin-ELF/mkiss     /usr/local/sbin
	install -m 755 -s -o bin -g bin bin-ELF/netromd   /usr/local/sbin
	install -m 755    -o bin -g bin src/noderest      /usr/local/sbin
	install -m 755    -o bin -g bin src/nodesave      /usr/local/sbin
	install -m 755 -s -o bin -g bin bin-ELF/nrparms   /usr/local/sbin
	install -m 755 -s -o bin -g bin bin-ELF/rip98d    /usr/local/sbin
else
	echo "Installing a.out binaries..."

	install -m 755 -s -o bin -g bin bin-a.out/call      /usr/local/bin
	install -m 4755 -s -o root -g bin bin-a.out/listen  /usr/local/bin
	install -m 755 -s -o bin -g bin bin-a.out/mheard    /usr/local/bin
	install -m 755 -s -o bin -g bin bin-a.out/pms       /usr/local/bin
	install -m 755 -s -o bin -g bin bin-a.out/axattach  /usr/local/sbin
	install -m 755 -s -o bin -g bin bin-a.out/ax25d     /usr/local/sbin
	install -m 755 -s -o bin -g bin bin-a.out/axl       /usr/local/sbin
	install -m 755 -s -o bin -g bin bin-a.out/axparms   /usr/local/sbin
	install -m 755 -s -o bin -g bin bin-a.out/beacon    /usr/local/sbin
	install -m 755 -s -o bin -g bin bin-a.out/kissparms /usr/local/sbin
	install -m 755 -s -o bin -g bin bin-a.out/mkiss     /usr/local/sbin
	install -m 755 -s -o bin -g bin bin-a.out/netromd   /usr/local/sbin
	install -m 755    -o bin -g bin src/noderest        /usr/local/sbin
	install -m 755    -o bin -g bin src/nodesave        /usr/local/sbin
	install -m 755 -s -o bin -g bin bin-a.out/nrparms   /usr/local/sbin
	install -m 755 -s -o bin -g bin bin-a.out/rip98d    /usr/local/sbin
fi

echo "Installing configuration files..."

install -m 644 -o bin -g bin etc/ax25d.conf  /usr/local/etc
install -m 644 -o bin -g bin etc/axports     /usr/local/etc
install -m 644 -o bin -g bin etc/loggedin    /usr/local/pms
install -m 644 -o bin -g bin etc/nrbroadcast /usr/local/etc
install -m 644 -o bin -g bin etc/nrports     /usr/local/etc
install -m 644 -o bin -g bin etc/rip98.conf  /usr/local/etc

echo "Installing manual pages..."

install -m 644 -o bin -g bin man/call.1        /usr/local/man/man1
install -m 644 -o bin -g bin man/listen.1      /usr/local/man/man1
install -m 644 -o bin -g bin man/mheard.1      /usr/local/man/man1
install -m 644 -o bin -g bin man/ax25.4        /usr/local/man/man4
install -m 644 -o bin -g bin man/netrom.4      /usr/local/man/man4
install -m 644 -o bin -g bin man/axports.5     /usr/local/man/man5
install -m 644 -o bin -g bin man/nrports.5     /usr/local/man/man5
install -m 644 -o bin -g bin man/nrbroadcast.5 /usr/local/man/man5
install -m 644 -o bin -g bin man/rip98.conf.5  /usr/local/man/man5
install -m 644 -o bin -g bin man/axattach.8    /usr/local/man/man8
install -m 644 -o bin -g bin man/ax25d.8       /usr/local/man/man8
install -m 644 -o bin -g bin man/axl.8         /usr/local/man/man8
install -m 644 -o bin -g bin man/axparms.8     /usr/local/man/man8
install -m 644 -o bin -g bin man/beacon.8      /usr/local/man/man8
install -m 644 -o bin -g bin man/kissparms.8   /usr/local/man/man8
install -m 644 -o bin -g bin man/mkiss.8       /usr/local/man/man8
install -m 644 -o bin -g bin man/netromd.8     /usr/local/man/man8 
install -m 644 -o bin -g bin man/noderest.8    /usr/local/man/man8
install -m 644 -o bin -g bin man/nodesave.8    /usr/local/man/man8
install -m 644 -o bin -g bin man/nrparms.8     /usr/local/man/man8
install -m 644 -o bin -g bin man/rip98d.8      /usr/local/man/man8

echo "Installation completed."

exit 0
